import asyncio
from tomoe.pururin import get_pur
from tomoe.nhentai import get_nh
from tomoe.simplyh import get_sim
from tomoe.hentaifox import get_hfox
from tomoe.hentai2read import get_h2r
from tomoe.utils.misc import choose


class Tomoe():
    def __init__(self,
                 Pururin: str = choose().pururin,
                 Nhentai: str = choose().nhentai,
                 Simplyhentai: str = choose().simply,
                 Haentaifox: str = choose().hentaifox,
                 Hentai2read: str = choose().hentai2read):

        self.pururin = Pururin
        self.nhentai = Nhentai
        self.simply = Simplyhentai
        self.hentaifox = Haentaifox
        self.hentai2read = Hentai2read


Api = Tomoe()


def main():
    async def main_pururin():
        await asyncio.gather(get_pur(Api.pururin))

    async def main_nhentai():
        await asyncio.gather(get_nh(Api.nhentai))

    async def main_simply():
        await asyncio.gather(get_sim(Api.simply))

    async def main_hentaifox():
        await asyncio.gather(get_hfox(Api.hentaifox))

    async def main_hentai2read():
        await asyncio.gather(get_h2r(Api.hentai2read))

    if Api.pururin is not None:
        asyncio.run(main_pururin())

    elif Api.nhentai is not None:
        asyncio.run(main_nhentai())

    elif Api.simply is not None:
        asyncio.run(main_simply())

    elif Api.hentaifox is not None:
        asyncio.run(main_hentaifox())

    elif Api.hentai2read is not None:
        asyncio.run(main_hentai2read())

    else:
        print("No arguments was given")


if __name__ == '__main__':
    main()



import janda
import json
import requests
import os
import re
import time
from .utils.misc import choose, split_name

h2r = janda.Hentai2read() 


async def get_h2r(id: str = choose().hentai2read):
    data = await h2r.get(id)
    parser = json.loads(data)
    title = parser['title']
    title = re.sub(r'[^\w\s]','', title)
    print(f'Title: {title}')

    img = parser['images']
    print(f'Total image: {len(img)}')
    neat_dir = split_name(__file__) + " - " + title
    
    if not os.path.exists(neat_dir):
        os.makedirs(neat_dir)

    if len(img) == len(os.listdir(neat_dir)):
        print("All images already downloaded! If you're doubt kindly remove this folder and re-download")
        print(f'Directory: {os.path.abspath(neat_dir)}')
        return

    for i in img:
        start = time.time()
        img_url = i
        img_name = img_url.rsplit('/', 1)[-1]

        r = requests.get(f'https://static.hentaicdn.com/hentai{img_url}')
        with open(neat_dir + '/' + img_name, 'wb') as f:
            f.write(r.content)
     
            if os.path.exists(neat_dir + '/' + img_name):
                print(f'Successfully downloaded {img_name} | in {time.time() - start:.2f} seconds')
            
            if len(img) == len(os.listdir(neat_dir)):
                print("All images downloaded!")
                with open(neat_dir + '/gallery.html', 'w') as f:
                    f.write('<html><body>')
                    for i in os.listdir(neat_dir):
                        f.write(f'<img src="{i}">')
                    f.write('</body></html>')

                    print(f'Static gallery saved to {neat_dir}/gallery.html')
                    print(f'Directory: {os.path.abspath(neat_dir)}')



import argparse
import os

def choose():
    my_parser = argparse.ArgumentParser()
    my_parser.add_argument('--nhentai', action='store', type=int)
    my_parser.add_argument('--pururin', action='store', type=int)
    my_parser.add_argument('--simply', action='store', type=str)
    my_parser.add_argument('--hentaifox', action='store', type=int)
    my_parser.add_argument('--hentai2read', action='store', type=str)
    
    args = my_parser.parse_args()
    return args

def split_name(string):
    get_name = os.path.basename(string).split('.')[0]
    return get_name


import re
from setuptools import setup

version = ''
with open('tomoe/__init__.py') as f:
    version = re.search(
        r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', f.read(), re.MULTILINE).group(1)


requirements = []
with open('requirements.txt') as f:
    requirements = f.read().splitlines()


if not version:
    raise RuntimeError('version is not set')

readme = ''
with open('README.md', encoding="utf8") as f:
    readme = f.read()

setup(
    name='tomoe',
    author='sinkaroid',
    author_email='anakmancasan@gmail.com',
    version=version,
    long_description=readme,
    long_description_content_type='text/markdown',
    url='https://github.com/sinkaroid/tomoe',
    project_urls={
        "Documentation": "https://sinkaroid.github.io/tomoe",
        "Issue tracker": "https://github.com/sinkaroid/tomoe/issues/new/choose",
        "Funding": "https://paypal.me/sinkaroid",
    },
    packages=['tomoe', 'tomoe.utils'],
    license='MIT',
    classifiers=[
        "Framework :: AsyncIO",
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Customer Service',
        'License :: OSI Approved :: MIT License',
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Environment :: Console",
        'Programming Language :: Python :: 3.7',
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Games/Entertainment",

    ],
    description='A doujinshi downloader for mankind',
    include_package_data=True,
    entry_points={
        'console_scripts': [
            'tomoe = tomoe:main',
        ]
    },
    install_requires=requirements,
)



__version__ = "2.0.2"
from .pururin import get_pur
from .nhentai import get_nh
from .hentaifox import get_hfox
from .hentai2read import get_h2r
from .simplyh import get_sim
from .cli import *
from .utils.misc import choose